      program InsolaSA
*******************************************************************************
*              Computation of the various insolation functions
*
*              This program uses InsolaSA.par : parameters for InsolaSA.f
*Stand-Alone insolation calcultion code
*               Revision of insola.f by L. David Roper, 12 Dec 2003
*
*   the following parameters are taken from the NAMELIST InsolaSA.par
*           pas         : stepsize (years)                                    *
*           datefin     : final time (million of years)                       *
*           datedebut   : starting time  (million of years)                   *
*           so          : solar constant   W*m^-2                        
*   other parameters:                                                         *                                                                             *
*           nbf         : 4 (number of variables)                             *
*           nbel1       : 4 + 1                                               *
*           nacd        : numbers of n-uplets in a record                     *
*                                                                             *
*  (c) Astronomie et Systemes Dynamiques/ Bureau des Longitudes (1993)        *
*  J. Laskar, F. Joutel                                                       *
*  version 0.82 (7/7/1993)                                                    *
*  version 0.83 (27/1/93)                                                     *
*******************************************************************************

      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      parameter(nacd=100,nbel=5,nbf=4)
      dimension Tel(nbf)
      character *50 fichout,nomascpos,nomascneg,nomprecpos,
     *nomprecneg
      common/cdo/so
      common/date/pas,itdebut
c
      NAMELIST/NAMSTD/nomascpos,nomascneg,nomprecpos,nomprecneg,
     *pas,datedebut,datefin,so
      open(18,file='InsolaSA.par',form='formatted',status='old')
      read(18,NAMSTD)
      close(18)
c
c Les fichiers ont une longueur d'enregistrement correspondant
c a 100 000 ans.
      open(11,file=nomascneg,status='old')
c
      read(11,*) debut
      itdebut=int(debut)
      close(11)          
c Nombre de lignes lues:
      datedebut=datedebut*1.D6
      datefin=datefin*1.D6
      aux=dabs(datefin-datedebut)
      npt=int((aux/dabs(pas))+1)
*-----------------------------------------------------------------------
*   principal menu
*-----------------------------------------------------------------------
      write (*,*) '***************************************************'
      write (*,*) '*                  InsolaSA                       *'
      write (*,*) '*                                                 *'
      write (*,*) '*   computation of various insolation quantities  *'
      write (*,*) '*                                                 *'
      write (*,*) '*     (c) ASD/BdL (1993) Revised LDR (2003)       *'
      write (*,*) '***************************************************'
999   continue
      write (*,*)
      write (*,*) '    1 : mean daily    insolation/true longitude '
      write (*,*) '    2 : mean daily    insolation/mean longitude '
      write (*,*) '    3 : mean monthly  insolation '
      write (*,*) '    4 : mean annual   insolation '
      write (*,*) '    5 : HELP'
      write (*,*) '    6 : QUIT'
      write (*,*)
      write (*,*) ' your choice ? '
      read  (*,*) ICHOI
      GOTO (1000,2000,3000,4000,5000,7000), ICHOI
      write (*,*) ' incorrect choice '
      GOTO 999
*---------------------------------- mean daily/ true longitude
1000  CONTINUE
      write (*,*)' Latitude on the Earth (in degrees) ? '
      read (*,*)  phi
      write (*,*) ' latitude = ',phi
      write (*,*)' True longitude (in degrees) ?'
      read (*,*) datejour
      write (*,*) 'true longitude = ',datejour
      phidegrees=phi
      phi=phi*pi/180.d0
      GOTO 6000

*---------------------------------- mean daily/ mean longitude
2000  CONTINUE
      write (*,*)' Latitude on the Earth (in degrees) ? '
      read (*,*)  phi
      write (*,*) ' latitude = ',phi
      write (*,*)
     $'approximate conventional dates for a given mean longitude'
      write (*,*)
      write (*,*)'  0: 21 march    '
      write (*,*)' 30: 21 april    '
      write (*,*)' 60: 21 may      '
      write (*,*)' 90: 21 june     '
      write (*,*)'120: 21 july     '
      write (*,*)'150: 21 august   '
      write (*,*)'180: 21 september'
      write (*,*)'210: 21 october  '
      write (*,*)'240: 21 november '
      write (*,*)'270: 21 december  '
      write (*,*)'300: 21 january   '
      write (*,*)'330: 21 february  '
      write (*,*)
      write (*,*)' Mean longitude (in degrees)  (0-360)?'
      read (*,*) datecal
      write (*,*) 'Mean longitude = ',datecal
      phidegrees=phi
      phi=phi*pi/180.d0
      GOTO 6000
*---------------------------------- mean monthly
3000  CONTINUE
      write (*,*)' Latitude on the Earth (in degrees) ? '
      read (*,*)  phi
      write (*,*) ' latitude = ',phi
      write (*,*)
      write (*,*)'approximate conventional dates of the months'
      write (*,*)
      write (*,*)' 1: 21 december  - 20 january'
      write (*,*)' 2: 21 january   - 20 february'
      write (*,*)' 3: 21 february  - 20 march'
      write (*,*)' 4: 21 march     - 20 april'
      write (*,*)' 5: 21 april     - 20 may'
      write (*,*)' 6: 21 may       - 20 june'
      write (*,*)' 7: 21 june      - 20 july'
      write (*,*)' 8: 21 july      - 20 august'
      write (*,*)' 9: 21 august    - 20 september'
      write (*,*)'10: 21 september - 20 october'
      write (*,*)'11: 21 october   - 20 november'
      write (*,*)'12: 21 november  - 20 december'
      write (*,*)
      write (*,*) 'Your choice ? (1-12)'
      read (*,*) moiscal
      write (*,*) 'month = ',moiscal
      phidegrees=phi
      phi=phi*pi/180.d0
      GOTO 6000
*---------------------------------- mean annual
4000  CONTINUE
      GOTO 6000
*--------------------------- Computation of insolation ------------
6000  continue
      write (*,*)
      write (*,*) 'Name of the output file'
      read(*,1010) fichout
1010  format (A)
      write(*,*) 'Begin date = ',datedebut,' End date = ',datefin
      open(22,file = fichout,form='formatted')
      GO TO (1099,2099,3099,4099), ICHOI
1098  FORMAT(f10.0,5x,f15.0)
1099  write(22,*) 'Latitude()       True Longitude in '
      write(22,1098) phidegrees,datejour
      go to 6099
2099  write(22,*) 'Latitude()       Mean Longitude()'
      write(22,1098) phidegrees,datecal
      go to 6099
3099  write(22,*) 'Latitude()       Month'
      write(22,1098) phidegrees,moiscal
      go to 6099
4099  continue
6099  continue
      write(22,*) 'Year(x10^3)       Insolation(W/m^2)'
      tps=datedebut
      nneg=1
      npos=1
      do i=1,npt
         if(tps.le.0) then
            if(nneg.EQ.1) then
               open(11,file=nomascneg,status='old')
               open(12,file=nomprecneg,status='old')
               nneg=nneg+1
            end if
            call yearsneg(tps,Tel)
         else
            if(npos.EQ.1) then
               open(13,file=nomascpos,status='old')
               open(14,file=nomprecpos,status='old')
               npos=npos+1
            end if
            call yearspos(tps,Tel)
         end if
         ak=Tel(1)
         ah=Tel(2)
         eps=Tel(3)
         psi=Tel(4)
         goto (6100,6200,6300,6400) ICHOI

6100     continue
         call wjour(datejour,ak,ah,eps,psi,phi,w)
         goto 6666

6200     continue
         call wjcal(datecal,ak,ah,eps,psi,phi,w)
         goto 6666

6300     continue
         call wmcal(moiscal,ak,ah,eps,psi,phi,w)
         goto 6666

6400     continue
         call wam(ak,ah,w)
         goto 6666

6666     continue
         write(22,1020) tps*1D-3,w 
1020  format(1x,f10.0,f20.2)
         tps=tps+pas
      end do
      close (22)
      close(11)
      close(12)
      close(13)
      close(14)
      GOTO 999
*--------------------------- HELP ------------------------------------
5000  write (*,*)
      write (*,*)' 1,2 :'
      write (*,*)'The daily insolation is computed for a given latitude'
      write (*,*)'of the Earth, and for a given position of the Earth '
      write (*,*)'on its orbit. This position is sometime given by a '
      write (*,*)'conventional date where the origine is at the moving'
      write (*,*)'equinox with conventional date 21 march'
      write (*,*)'As this terminology is confusing, in the present '
      write (*,*)'program, the position of the Earth on its orbit is'
      write (*,*)'given either by its true longitude (1), or by the'
      write (*,*)'mean longitude (2), both expressed in degrees'
      write (*,*)'with origine at the moving equinox'
      write (*,*)
      write (*,*)'The true longitude is the true position angle of the'
      write (*,*)'Sun-Earth direction with respect to the equinox. '
      write (*,*)'The mean longitude is a fictif angle which is '
      write (*,*)'described by the Earth at constant velocity.'
      write (*,*)'The mean longitude is thus proportional to the time,'
      write (*,*)'and  should be the normal choice in many cases.'
      write (*,*)
      write (*,*)
      write (*,*) ' press RETURN for MORE '
      PAUSE
      write (*,*)' 3 :'
      write (*,*)' The monthly insolation correspond to the mean daily'
      write (*,*)'insolation over 1/12 of a year, that is 30 degrees'
      write (*,*)'of mean longitude, with origine at the equinox.'
      write (*,*)
      write (*,*)' 4 :'
      write (*,*)'The mean annual insolation is computed over a full'
      write (*,*)'revolution of the Earth around the Sun.'
      write (*,*)
      write (*,*)
      GOTO 999
7000  CONTINUE
      write(*,*) 'Insolation program exited.'
      end
************************************************************************
*  subroutines for the computation of insolation
*  J. Laskar, F. Joutel, F. Boudin
* (c) Astronomie et Systemes Dynamiques/ Bureau des Longitudes (1993)
*
*************************************************************************
       subroutine vraimoy(hl,e,pibar,hlm)
c***********************************************************************
c  calcule la longitude moyenne (hlm) en fonction de la longitude      *
c  vraie (hl), de l'excentricite (e) et de la longitude du perihelie   *
c  (pibar)                                                             *
c  (c) ASD/BDL (1/10/92)  
c  correction  27/1/93                                                 *
c***********************************************************************
      implicit double precision (a-h,p-y)
      beta = (1-e**2)**0.5D0
      eM = hl-pibar
      hlm = hl - 2.D0*(e/2.D0+e**3/8.D0)*(1+beta)*sin(eM)
     & -e**2/4.D0*(0.5D0+beta)*sin(2.D0*eM)
     & +e**3*(1/3.D0+beta)*sin(3.D0*eM)
      return
      end

      subroutine moyvrai(hlm,e,pibar,hl)
c***********************************************************************
c  calcule la longitude vraie (hl) en fonction de la longitude         *
c  moyenne (hlm), de l'excentricite (e) et de la longitude du          *
c  perihelie (pibar)                                                   *
c  (c) ASD/BDL (1/10/92)
c***********************************************************************
      implicit double precision (a-h,p-y)
      eM = hlm-pibar
      hl = hlm + (2.D0*e-e**3/4.D0)*sin(eM)
     &+5.D0/4.D0*e**2*sin(2.D0*eM)
     &+13.D0/12.D0*e**3*sin(3.D0*eM)
      return
      end

       SUBROUTINE cwj(wd,e,pibar,eps,phi,w)
c***********************************************************************
c                                                                      *
c      INSOLATION JOURNALIERE D'UN POINT DE LATITUDE DONNEE            *
c                                                                      *
c A L'ENTREE:                                                          *
c   wd : la longitude vraie du soleil (en radian)  compte a partir    *
c        de l'equinoxe de la date                                      *
c   e : excentricite                                                   *
c   pibar: longitude du perihelie comptee a partir de l'equinoxe de la *
c   date + pi (repere geocentrique)                                    *
c   eps: l'obliquite                                                   *
c   phi: latitude du point sur la terre                                *
c                                                                      *
c EN SORTIE:                                                           *
c   w:l'insolation journaliere d'un point de latitude donnee           *
c  (c) ASD/BDL (1/10/92)                                              *
c***********************************************************************
      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      common/cdo/so
c
c-----------------------------------------------------------------------
c     CALCUL D'INSOLATION
c-----------------------------------------------------------------------
c anomalie vraie (v):
      v = wd-pibar
c
c Distance terre-soleil (rho):
      cosv= cos(v)
      aux=1+e*cosv
      rho=(1-e**2)/aux
c
c Declinaison du soleil (delta):
      sinusdelta=sin(eps)*sin(wd)
      delta=asin(sinusdelta)
c
c
c LATITUDES DE LEVER ET COUCHER DE SOLEIL:
c^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
      aux=pi/2.d0-abs(delta)
      if ((-aux).lt.phi.and.phi.lt.aux) then
c |Angle horaire| du lever et coucher du soleil (ho):
          cho=-tan(phi)*tan(delta)
          ho=acos(cho)
c Insolation (w)
          w=(ho*sin(phi)*sin(delta)+cos(phi)*cos(delta)*sin(ho))
          w=w*so/(pi*rho**2)
          goto 200
      endif
c
c LATITUDES SANS COUCHER:
c^^^^^^^^^^^^^^^^^^^^^^^^
      a1=pi/2.d0-delta
      a2=pi/2.d0+delta
      if (phi.ge.a1.or.phi.le.(-a2)) then
          w=so*sin(phi)*sin(delta)/rho**2
          goto 200
      endif
c
c LATITUDES SANS LEVER:
c^^^^^^^^^^^^^^^^^^^^^^
      if (phi.le.(-a1).or.phi.ge.a2) w=0.d0
c
 200  return
      end


      SUBROUTINE wmcal(mois,ak,ah,eps,psi,phi,w)
c***********************************************************************
c
c      INSOLATION MENSUELLE D'UN POINT DE LATITUDE DONNEE
c
c A L'ENTREE:
c   mois : le numero du mois  (l'annee est divisee en 12 mois de 30
c          degres et le numero 3 correspond a  fin fevrier- fin mars)
c   ak,ah,eps,psi: les elements orbitaux pour la date tps
c   ak:k
c   ah:h
c   eps:l'obliquite
c   psi:precession en longitude
c   phi: latitude du point sur la terre
c
c EN SORTIE:
c   w:l'insolation mensuelle d'un point de latitude donnee
c (c) ASD/BDL (1/10/92)
c***********************************************************************
      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      common/cdo/so
      common/cfunc/e,pibar,phidu,epsdu
      external F
c variables 'dummy'
      phidu=phi
      epsdu=eps
c-----------------------------------------------------------------------
c     CALCUL D'INSOLATION
c-----------------------------------------------------------------------
c longitude du perihelie par rapport a l'equinoxe de reference(pitild),
c par rapport a l'equinoxe de la date(pitbar), excentricite(e):
      pitild=atan2(ah,ak)
      pibar=pitild+psi+pi
      e=dsqrt(ah**2+ak**2)
c
c Longitude moyenne au 21 mars
c
      call vraimoy(0.D0,e,pibar,hlm0)
c
c  longitude moyenne (hlm1) et vraie (hl1) au debut du mois
      hlm1 = hlm0+(mois-4)*pi*30.D0/180D0
c longitude moyenne (hlm2) et vraie (hl1) a la fin du mois
      hlm2 = hlm1+30.D0*pi/180D0
c calcul de l'insolation moyenne a l'aide de la
c methode de Romdberg
      call qromb(F,hlm1,hlm2,w)
      w=w/30.D0/pi*180.D0
      return
      end

c***********************************************************************
      double precision function F(hlm)
      implicit double precision (a-h,p-y)
      common/cfunc/e,pibar,phi,eps
      call moyvrai(hlm,e,pibar,hl)
      call cwj(hl,e,pibar,eps,phi,w)
      F=w
      return
      end


      SUBROUTINE wjour(date,ak,ah,eps,psi,phi,w)
c***********************************************************************
c
c      INSOLATION JOURNALIERE D'UN POINT DE LATITUDE DONNEE
c
c A L'ENTREE:
c   date : la longitude vraie du soleil (en degres)  comptee a partir
c          de l'equinoxe vrai
c   ak,ah,eps,psi: les elements orbitaux pour la date tps
c   ak:k
c   ah:h
c   eps:l'obliquite
c   psi:precession en longitude
c   phi: latitude du point sur la terre
c
c EN SORTIE:
c   w:l'insolation journaliere d'un point de latitude donnee
c (c) ASD/BDL (1/10/92)
c***********************************************************************
      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      common/cdo/so
c-----------------------------------------------------------------------
c     CALCUL D'INSOLATION
c-----------------------------------------------------------------------
c longitude du perihelie par rapport a l'equinoxe de reference(pitild),
c par rapport a l'equinoxe de la date(pibar), excentricite(e):
      pitild=atan2(ah,ak)
      pibar=pitild+psi+pi
      e=dsqrt(ah**2+ak**2)
c
c Longitude vraie comptee a partir de l'equinoxe vrai et
c anomalie vraie (wd,v):
      hl = date*pi/180.D0
      call cwj(hl,e,pibar,eps,phi,w)
      end


      SUBROUTINE wjcal(datecal,ak,ah,eps,psi,phi,w)
c***********************************************************************
c
c      INSOLATION JOURNALIERE D'UN POINT DE LATITUDE DONNEE
c
c A L'ENTREE:
c   datecal: la longitude moyenne (en degres) du soleil comptee a partir
c          de l'equinoxe de la date
c   ak,ah,eps,psi: les elements orbitaux pour la date tps
c   ak:k
c   ah:h
c   eps:l'obliquite
c   psi:precession en longitude
c   phi: latitude du point sur la terre
c
c EN SORTIE:
c   w:l'insolation journaliere d'un point de latitude donnee
c (c) ASD/BDL (1/10/92)
c***********************************************************************
      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      common/cdo/so
c
c-----------------------------------------------------------------------
c     CALCUL D'INSOLATION
c-----------------------------------------------------------------------
c
c longitude du perihelie par rapport a l'equinoxe de reference(pitild),
c par rapport a l'equinoxe de la date(pibar), excentricite(e):
      pitild=atan2(ah,ak)
      pibar=pitild+psi+pi
      e=dsqrt(ah**2+ak**2)
c calcul de la longitude vraie
      hlm=datecal*pi/180.D0
c longitude moyenne au 21 mars
      call vraimoy(0.D0,e,pibar,hlm0)
c longitude moyenne a la date
      hlm=hlm0+hlm
c longitude vraie a la date
      call moyvrai(hlm,e,pibar,wd)
      call cwj(wd,e,pibar,eps,phi,w)
      end

      SUBROUTINE Telinsol(tps,Tel)
c Not used any more: replace by yearsneg and yearspos
c********************************************************************
c           LES ELEMENTS CLIMATIQUES k,h,eps,phi
c           POUR UNE DATE DONNEE tps (en nombre entier de pas).
c A L'ENTREE:
c  tps : la date pour laquelle on dsire les elements (en annees)
c EN SORTIE:
c  Tel(nbf) : tableau des lments orbitaux (k,h,eps,phi) pour la
c             date tps
c  (c) ASD/BDL (1/10/92)
c********************************************************************
      implicit double precision (a-h,o-z)
      parameter (nbel1=5,nbf=4)
      parameter (nacd=100)
      dimension Tel(nbf),Taux(nbel1,nacd)
      common/date/pas,itdebut
      data ncour /-1/
      save ncour
      save Taux
c nrec est le numero d'ordre de l'enregistrement qui contient tps
      tt=tps/abs(pas)
c itt est l'entier le plus proche  de tt
      itt=nint(tt)
      nrec=(itt-itdebut)/nacd+1
      if (nrec.ne.ncour) then
         if(tps.le.0) then
            call yearsneg(Taux)
         else
            call yearspos(Taux)
         end if
         ncour=nrec
      endif
      itdeb=itdebut+(nrec-1)*nacd
      iplace=itt-itdeb+1
      do i=2,nbel1
         Tel(i-1)=Taux(i,iplace)
      end do
      end

      SUBROUTINE wam(ak,ah,w)
c***********************************************************************
c
c                  INSOLATION  ANNUELLE MOYENNEE
c
c A L"ENTREE:
c  ak,ah:elements orbitaux pour une date donnee
c  ak:k
c  ah:h
c
c EN SORTIE:
c  w:insolation annuelle moyenne
c  (c) ASD/BDL (1/10/92)
c***********************************************************************
      implicit double precision(a-h,o-z)
      parameter(pi=3.1415926535897932d0)
      common/cdo/so
c-----------------------------------------------------------------------
c     CALCUL D'INSOLATION
c-----------------------------------------------------------------------
c excentricite (e):
      e=dsqrt(ah**2+ak**2)
c Carre de la distance terre-soleil moyennee sur une revolution (rho):
      rho=dsqrt(1-e**2)
c Calcul d"insolation (w):
      w=(so)/(4*rho)
      return
      end


      SUBROUTINE soresul(ifich,x,y)
c***********************************************************************
c
c                     SORTIE DES RESULTATS
c
c  PARAMETRES D'ENTREE:
c  ifich : le numero de connection du fichier de sortie
c  x     :la date
c  y     : la valeur de la fonction de la date x
c (c) ASD/BDL (1/10/92)
c***********************************************************************
c
      implicit double precision (a-h,o-z)
      logical ecriture
      common/fichier/ecriture
c
1000  format(1x,f10.0,d24.16)
      if (ecriture) then
        write(ifich,1000) x*1D-3,y
      else
        write(*,1000) x*1D-3,y
      endif
      return
      end


      SUBROUTINE qromb(FUNC,A,B,SS)
c******************************************************************************
c   NUMERICAL RECIPES                                                         *
c   ROMBERG INTEGRATION                                                       *
c******************************************************************************
      IMPLICIT DOUBLE PRECISION (A-H,P-Y)
      EXTERNAL FUNC
      PARAMETER(EPS=1.D-6,JMAX=20,JMAXP=JMAX+1,K=5,KM=4)
      DIMENSION S(JMAXP),H(JMAXP)
      H(1)=1.
      DO 11 J=1,JMAX
        CALL TRAPZD(FUNC,A,B,S(J),J)
        IF (J.GE.K) THEN
          L=J-KM
          CALL POLINT(H(L),S(L),K,0.,SS,DSS)
          IF (ABS(DSS).LT.EPS*ABS(SS)) RETURN
        ENDIF
        S(J+1)=S(J)
        H(J+1)=0.25*H(J)
11    CONTINUE
      PAUSE 'Too many steps.'
      END

************************************************************************
      SUBROUTINE POLINT(XA,YA,N,X,Y,DY)
      IMPLICIT DOUBLE PRECISION (A-H,P-Y)
      PARAMETER (NMAX=10)
      DIMENSION XA(N),YA(N),C(NMAX),D(NMAX)
      NS=1
      DIF=ABS(X-XA(1))
      DO 11 I=1,N
        DIFT=ABS(X-XA(I))
        IF (DIFT.LT.DIF) THEN
          NS=I
          DIF=DIFT
        ENDIF
        C(I)=YA(I)
        D(I)=YA(I)
11    CONTINUE
      Y=YA(NS)
      NS=NS-1
      DO 13 M=1,N-1
        DO 12 I=1,N-M
          HO=XA(I)-X
          HP=XA(I+M)-X
          W=C(I+1)-D(I)
          DEN=HO-HP
          IF(DEN.EQ.0.)PAUSE
          DEN=W/DEN
          D(I)=HP*DEN
          C(I)=HO*DEN
12      CONTINUE
        IF (2*NS.LT.N-M)THEN
          DY=C(NS+1)
        ELSE
          DY=D(NS)
          NS=NS-1
        ENDIF
        Y=Y+DY
13    CONTINUE
      RETURN
      END

************************************************************************
      SUBROUTINE TRAPZD(FUNC,A,B,S,N)
      IMPLICIT DOUBLE PRECISION (A-H,P-Y)
      EXTERNAL FUNC
      SAVE IT
      IF (N.EQ.1) THEN
        S=0.5*(B-A)*(FUNC(A)+FUNC(B))
        IT=1
      ELSE
        TNM=IT
        DEL=(B-A)/TNM
        X=A+0.5*DEL
        SUM=0.
        DO 11 J=1,IT
          SUM=SUM+FUNC(X)
          X=X+DEL
11      CONTINUE
        S=0.5*(S+(B-A)*SUM/TNM)
        IT=2*IT
      ENDIF
      RETURN
      END

************************************************************************      
      subroutine yearsneg(tps,TX)
*-----------------------------------------------------------------------
*      This subroutine uses the ascii files containing
*      the necessary quantities t,k,h,eps,phi
*      which are used for the computation of the insolation
*      quantities by the program InsolSA
*---------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      parameter(nbf=4)
      dimension TX(nbf)
c
      t=.5
      tt=tps/1000.d0
      ntimes=1
      do while (ntimes.EQ.1)
         do while (t.NE.tt)
            read(11,*,end=300) t
            read(12,*,end=300) t
         end do
         backspace 11
         backspace 12
         ntimes=ntimes+1
      end do
      
      read(11,*,end=300) t,rk,rh,rq,rp
      read(12,*,end=300) t,eps,rphi
      backspace 11
      backspace 11
      backspace 12
      backspace 12
      TX(1)=rk
      TX(2)=rh
      TX(3)=eps
      TX(4)=rphi
      go to 300    
c
99    write(*,*)'yearsneg erreur!'
      stop
300   continue
      return
      end

************************************************************************      
      subroutine yearspos(tps,TX)
*-----------------------------------------------------------------------
*      This subroutine uses the ascii files containing
*      the necessary quantities t,k,h,eps,phi
*      which are used for the computation of the insolation
*      quantities by the program InsolSA       
*---------------------------------------------------------------------
      implicit double precision (a-h,o-z)
      parameter(nbf=4)
      dimension TX(nbf)
c
      t=0.5
      tt=tps/1000.d0
      ntimes=1
      do while (ntimes.EQ.1)
         do while (t.NE.tt)
            read(13,*,end=300) t
            read(14,*,end=300) t
         end do
         backspace 13
         backspace 14
         ntimes=ntimes+1
      end do
      read(13,*,end=300) t,rk,rh,rq,rp
      read(14,*,end=300) t,eps,rphi
      TX(1)=rk
      TX(2)=rh
      TX(3)=eps
      TX(4)=rphi
      go to 300
c
99    write(*,*)'yearspos erreur!'
      stop
300   continue
      return
      end
